More structures
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   time.rst
   printTime.rst
   functions_for_objects.rst
   pure_functions.rst
   const_parameters.rst
   modifiers.rst
   fillin_functions.rst
   which_is_best.rst
   incremental_development.rst
   generalization.rst
   algorithms.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst